Crate logbook_dy

Crate logbook_dy 

Records observations in a logbook file, or lists previous observations.

Functions

append
Appends msg to the logbook file at path, creating the file if necessary.
read
Reads the contents of a logbook at file path.